@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_ACLJOBBASE_H
-#define KIMAP_ACLJOBBASE_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -52,12 +51,10 @@ public:
     /**
      * The mailbox that will be acted upon.
      */
-    QString mailBox() const;
+    [[nodiscard]] QString mailBox() const;
 
 protected:
     explicit AclJobBase(JobPrivate &dd);
 };
 
 }
-
-#endif
